@@ -1,9 +1,11 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import shutil
 import sys
 from datetime import datetime
 from optparse import OptionParser
+from os import getenv
 from pathlib import Path, PurePath
 from sys import stderr
 from time import sleep as time_sleep
@@ -11,12 +13,6 @@ from typing import Optional
 
 import json5 as json
 
-try:
-    import vlc
-except OSError:
-    print("vlc not found.", file=sys.stderr)
-    sys.exit(1)
-
 from exclock import __VERSION__
 from exclock.entities import ClockTimer
 from exclock.util import (
@@ -31,6 +27,12 @@ from exclock.util import (
     notify_all,
 )
 
+try:
+    import vlc
+except OSError:
+    print("vlc not found.", file=sys.stderr)
+    sys.exit(1)
+
 
 def get_title_from_json_filename(json_filename: str) -> str:
     basename = PurePath(json_filename).name
@@ -76,7 +78,7 @@ def check_raw_clock(d) -> None:
 
 
 def get_option_parser():
-    usage = "exclock [(filename) | --list | --time {time}]"
+    usage = "exclock [options] {clock-filename}"
     parser = OptionParser(usage=usage, version=__VERSION__)
     parser.add_option(
         "-l",
@@ -91,7 +93,23 @@ def get_option_parser():
         "--time",
         dest="specified_time",
         action="store",
-        help="Time which spends until or to specified")
+        help="Time which spends until or to specified",
+    )
+    parser.add_option(
+        "-r",
+        "--ring-filename",
+        dest="ring_filename",
+        action="store",
+        help="filename which is used for alarm",
+    )
+    parser.add_option(
+        "--trace",
+        "--traceback",
+        default=False,
+        action="store_true",
+        dest="with_traceback",
+        help="show traceback",
+    )
 
     return parser
 
@@ -113,6 +131,20 @@ def get_time(time_: str) -> Optional[int]:
     return None
 
 
+def get_ring_filename(ring_sound_filename: Optional[str]) -> str:
+
+    def _get_ring_filename() -> str:
+        ring_filename_in_sys = getenv('EXCLOCK_RING_FILENAME')
+        if ring_sound_filename is None and ring_filename_in_sys is None:
+            return "__warning.mp3"
+        elif ring_sound_filename is None:
+            return str(ring_filename_in_sys)
+        else:
+            return str(ring_sound_filename)
+
+    return get_real_sound_filename(_get_ring_filename())
+
+
 def specified_time_main(opt, args) -> None:
     time_sec = get_time(opt.specified_time)
     if time_sec is None:
@@ -120,11 +152,15 @@ def specified_time_main(opt, args) -> None:
         sys.exit(1)
 
     try:
+        ring_sound_filename = get_ring_filename(opt.ring_filename)
+        if not Path(ring_sound_filename).exists():
+            print("Ring filename is not found.", file=sys.stderr)
+            sys.exit(1)
+
         message = f"Specified time is passed(sec={time_sec})."
         notify_all(title="Exclock", message=message, spend_time=time_sec, is_first=False)
 
-        warning_sound_filename = get_real_sound_filename("__warning.mp3")
-        p = vlc.MediaPlayer(warning_sound_filename)
+        p = vlc.MediaPlayer(ring_sound_filename)
         p.play()
         while p.get_state() != vlc.State.Ended:
             time_sleep(0.2)
@@ -168,7 +204,15 @@ def play_clock_main(opt, args) -> None:
         print('bye')
 
 
+def check_requirements() -> None:
+    if not shutil.which("xmessage"):
+        print("xmessage not found.", file=sys.stderr)
+        sys.exit(1)
+
+
 def main() -> None:
+    check_requirements()
+
     opt, args = get_option_parser().parse_args()
 
     if opt.show_list:
